==> openshift-model-installer-6.8.1-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/DiskFluent.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiskFluent<A extends DiskFluent<A>> extends BaseFluent<A>{
  public DiskFluent() {
  }
  public DiskFluent(Disk instance) {
    instance = (instance != null ? instance : new Disk());

    if (instance != null) {
      this.withSizeGB(instance.getSizeGB());
      this.withSizeGB(instance.getSizeGB());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Long sizeGB;
  private Map<String,Object> additionalProperties;
  public Long getSizeGB() {
    return this.sizeGB;
  }
  public A withSizeGB(Long sizeGB) {
    this.sizeGB=sizeGB; return (A) this;
  }
  public boolean hasSizeGB() {
    return this.sizeGB != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskFluent that = (DiskFluent) o;
    if (!java.util.Objects.equals(sizeGB, that.sizeGB)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(sizeGB,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (sizeGB != null) { sb.append("sizeGB:"); sb.append(sizeGB + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-installer-6.9.0-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/DiskFluent.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DiskFluent<A extends DiskFluent<A>> extends BaseFluent<A>{
  public DiskFluent() {
  }
  
  public DiskFluent(Disk instance) {
    this.copyInstance(instance);
  }
  private Long sizeGB;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Disk instance) {
    instance = (instance != null ? instance : new Disk());
  
    if (instance != null) {
        this.withSizeGB(instance.getSizeGB());
        this.withSizeGB(instance.getSizeGB());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Long getSizeGB() {
    return this.sizeGB;
  }
  
  public A withSizeGB(Long sizeGB) {
    this.sizeGB=sizeGB; return (A) this;
  }
  
  public boolean hasSizeGB() {
    return this.sizeGB != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskFluent that = (DiskFluent) o;
    if (!java.util.Objects.equals(sizeGB, that.sizeGB)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(sizeGB,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (sizeGB != null) { sb.append("sizeGB:"); sb.append(sizeGB + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
